/*
 * Copyright (c) 2009-2012 Xilinx, Inc.  All rights reserved.
 *
 * Xilinx, Inc.
 * XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS" AS A
 * COURTESY TO YOU.  BY PROVIDING THIS DESIGN, CODE, OR INFORMATION AS
 * ONE POSSIBLE   IMPLEMENTATION OF THIS FEATURE, APPLICATION OR
 * STANDARD, XILINX IS MAKING NO REPRESENTATION THAT THIS IMPLEMENTATION
 * IS FREE FROM ANY CLAIMS OF INFRINGEMENT, AND YOU ARE RESPONSIBLE
 * FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE FOR YOUR IMPLEMENTATION.
 * XILINX EXPRESSLY DISCLAIMS ANY WARRANTY WHATSOEVER WITH RESPECT TO
 * THE ADEQUACY OF THE IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO
 * ANY WARRANTIES OR REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE
 * FROM CLAIMS OF INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 */

/*
 * helloworld.c: simple test application
 *
 * This application configures UART 16550 to baud rate 9600.
 * PS7 UART (Zynq) is not initialized by this application, since
 * bootrom/bsp configures it to baud rate 115200
 *
 * ------------------------------------------------
 * | UART TYPE   BAUD RATE                        |
 * ------------------------------------------------
 *   uartns550   9600
 *   uartlite    Configurable only in HW design
 *   ps7_uart    115200 (configured by bootrom/bsp)
 */

#include <stdio.h>

#include "xparameters.h"
#include "sg_plbiface.h"

// Define delay length
#define DELAY 2500000

void print(char *str);

int main()
{
	u32 x, phi, y, bw, alpha;
	int i, i1, i2, np;
	double inc;

	np = 40;
	inc = 1023./np;

	xc_iface_t *iface;
	xc_to_reg_t *toreg_in1;
	xc_to_reg_t *toreg_in2;
	xc_to_reg_t *toreg_in3;
	xc_from_reg_t *fromreg1;
	xc_from_reg_t *fromreg2;

	// initialize the software driver
	XC_CfgInitialize(&iface, &SG_PLBIFACE_ConfigTable[0]);

	XC_GetShmem(iface, "x", (void **) &toreg_in1);
	XC_GetShmem(iface, "phi", (void **) &toreg_in2);
	XC_GetShmem(iface, "y", (void **) &toreg_in3);
	XC_GetShmem(iface, "bw", (void **) &fromreg1);
	XC_GetShmem(iface, "alpha", (void **) &fromreg2);

	xil_printf("Starting...\r\n");

	y = 512;
	for (i1=0; i1<=np; i1+=1){
		x = i1*inc;
		for (i2=0; i2<=np; i2+=1){
			phi = i2* inc;
			// write input values to AXI registers
			XC_Write(iface, toreg_in1->din, (const unsigned) x);
			XC_Write(iface, toreg_in2->din, (const unsigned) phi);
			XC_Write(iface, toreg_in3->din, (const unsigned) y);
			// Wait for completing the inference process
			for (i=0; i<DELAY; i++);
			// read output data from AXI registers
			XC_Read(iface, fromreg1->dout, &bw);
			XC_Read(iface, fromreg2->dout, &alpha);
			// Print values of x, phi, y, bw, alpha to standard output
			xil_printf("%d\t%d\t%d\t%d\t%d\n\r", x, phi, y, bw, alpha);
		}
		xil_printf("\n\r");
	}

	xil_printf("\n\rfinished!....\n\r");

    return 0;
}
